locpy.api.LocAPI
================

.. currentmodule:: locpy.api

.. autoclass:: LocAPI

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~LocAPI.__init__
      ~LocAPI.dataset_uri_from_id
      ~LocAPI.retrieve_label
      ~LocAPI.rwo_uri_from_id
      ~LocAPI.search
      ~LocAPI.suggest
      ~LocAPI.uri_from_id
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~LocAPI.afset_base
      ~LocAPI.lcdgt_base
      ~LocAPI.lcgft_base
      ~LocAPI.lcmpt_base
      ~LocAPI.lcnaf_base
      ~LocAPI.lcsh_base
      ~LocAPI.lcsj_base
      ~LocAPI.rwo_base
      ~LocAPI.tgm_base
      ~LocAPI.uri_base
   
   